@@ -1,3 +1,4 @@
+/* -*- Mode: C;  c-basic-offset: 2; tab-width: 2; indent-tabs-mode: nil; -*- */
 /* ***** BEGIN LICENSE BLOCK *****
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -38,9 +39,13 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+const Ci = Components.interfaces;
+const Cr = Components.results;
+const Cc = Components.classes;
+
 // parameters to gCommonDialogParam.Get() are defined in nsPIPromptService.idl
 var gCommonDialogParam = 
-  window.arguments[0].QueryInterface(Components.interfaces.nsIDialogParamBlock);
+  window.arguments[0].QueryInterface(Ci.nsIDialogParamBlock);
   
 function showControls()
 {
@@ -101,12 +106,40 @@ function setLabelForNode(aNode, aLabel, aIsLabelFlag)
     aNode.accessKey = accessKey;
 }
 
+var softkbObserver = {
+ QueryInterface: function (aIID) {
+    if (aIID.equals(Ci.nsISupports) ||
+        aIID.equals(Ci.nsIObserver))
+      return this;
+    throw Cr.NS_ERROR_NO_INTERFACE;
+  },
+ observe: function(subject, topic, data) {
+    if (topic === "softkb-change") {
+      var rect = JSON.parse(data);
+      if (rect) {
+        var height = rect.bottom - rect.top;
+        var width = rect.right - rect.left;
+        var top = (rect.top + (height - window.innerHeight) / 2);
+        var left = (rect.left + (width - window.innerWidth) / 2);
+        window.moveTo(left, top);
+      }
+    }
+  }
+};
+
 function commonDialogOnLoad()
 {
+  // limit the dialog to the screen width
+  document.getElementById("filler").maxWidth = screen.availWidth;
+
   // set the document title
-//@line 110 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
+//@line 139 "/export/home/slave/ffslave/mozilla-1.9.2-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
   document.title = gCommonDialogParam.GetString(12);
-//@line 112 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
+//@line 141 "/export/home/slave/ffslave/mozilla-1.9.2-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
+
+  var observerService = Cc["@mozilla.org/observer-service;1"]
+                          .getService(Ci.nsIObserverService);
+  observerService.addObserver(softkbObserver, "softkb-change", false);
 
   // set the number of command buttons
   var nButtons = gCommonDialogParam.GetInt(2);
@@ -168,17 +201,23 @@ function commonDialogOnLoad()
     // Set the default button and focus it on non-OS X systems
     var dButton = dlgButtons[gCommonDialogParam.GetInt(5)];
     document.documentElement.defaultButton = dButton;
-//@line 174 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
+//@line 207 "/export/home/slave/ffslave/mozilla-1.9.2-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
     document.documentElement.getButton(dButton).focus();
-//@line 176 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
+//@line 209 "/export/home/slave/ffslave/mozilla-1.9.2-solaris-sparc-nightly/build/toolkit/content/commonDialog.js"
+  }
+  else {
+    if (gCommonDialogParam.GetInt(4) == 1)
+      document.getElementById("password1Textbox").select();
+    else
+      document.getElementById("loginTextbox").select();
   }
 
   if (gCommonDialogParam.GetInt(6) != 0) // delay button enable
   {
     var delayInterval = 2000;
     try {
-      var prefs = Components.classes["@mozilla.org/preferences-service;1"]
-                  .getService(Components.interfaces.nsIPrefBranch);
+      var prefs = Cc["@mozilla.org/preferences-service;1"]
+                    .getService(Ci.nsIPrefBranch);
       delayInterval = prefs.getIntPref("security.dialog_enable_delay");
     } catch (e) {}
 
@@ -196,19 +235,23 @@ function commonDialogOnLoad()
 
   // play sound
   try {
-    var sound = gCommonDialogParam.GetString(13);
+    var sound = gCommonDialogParam.GetInt(7);
     if (sound) {
-      Components.classes["@mozilla.org/sound;1"]
-                .createInstance(Components.interfaces.nsISound)
-                .playSystemSound(sound);
+      Cc["@mozilla.org/sound;1"]
+        .createInstance(Ci.nsISound)
+        .playEventSound(sound);
     }
   } catch (e) { }
 
-  var observerService = Components.classes["@mozilla.org/observer-service;1"]
-                                  .getService(Components.interfaces.nsIObserverService);
   observerService.notifyObservers(window, "common-dialog-loaded", null);
 }
 
+function commonDialogOnUnload(){
+  var observerService = Cc["@mozilla.org/observer-service;1"]
+                          .getService(Ci.nsIObserverService);
+  observerService.removeObserver(softkbObserver, "softkb-change");
+}
+
 var gDelayExpired = false;
 var gBlurred = false;
 
